pub struct JournalSet<'a> { /* private fields */ }Expand description
A set of journals, ordered by height and hash.
Implementations
Sourceimpl<'a> JournalSet<'a>
impl<'a> JournalSet<'a>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new JournalSet with the specified capacity.
Sourcepub fn from_journal(journal: Journal<'a>) -> Self
pub fn from_journal(journal: Journal<'a>) -> Self
Creates a new JournalSet from a single Journal.
Sourcepub fn earliest_height(&self) -> Option<u64>
pub fn earliest_height(&self) -> Option<u64>
Returns the earliest height of a journal in the set.
Sourcepub const fn latest_hash(&self) -> Option<B256>
pub const fn latest_hash(&self) -> Option<B256>
Returns the latest hash of a journal in the set.
Sourcepub const fn latest_height(&self) -> Option<u64>
pub const fn latest_height(&self) -> Option<u64>
Returns the latest height of a journal in the set.
Sourcepub fn get_by_rollup_height(&self, rollup_height: u64) -> Option<&Journal<'a>>
pub fn get_by_rollup_height(&self, rollup_height: u64) -> Option<&Journal<'a>>
Get the block at that height, if it is within the set.
Sourcepub fn range(&self) -> Option<RangeInclusive<u64>>
pub fn range(&self) -> Option<RangeInclusive<u64>>
Returns the range of heights in the set. If the set is empty, returns
None.
Sourcepub fn try_append(
&mut self,
journal: Journal<'a>,
) -> Result<(), JournalSetError<'a>>
pub fn try_append( &mut self, journal: Journal<'a>, ) -> Result<(), JournalSetError<'a>>
Push the journal into the set.
Sourcepub fn append_overwrite(
&mut self,
journal: Journal<'a>,
) -> Result<(), JournalSetError<'a>>
pub fn append_overwrite( &mut self, journal: Journal<'a>, ) -> Result<(), JournalSetError<'a>>
Appends the journal to the set, removing any journals that conflict with it.
This will only succeed if the journal is within the set’s range AND replacing the journal currently at that height would lead to a consistent history.